==> pyrestsdk-0.1.1.tar.gz: pyrestsdk-0.1.1/pyrestsdk/clientfactory/_abstract_client_factory.py <==
from requests import Session
from typing import TypeVar, List
from logging import getLogger
from abc import ABC, abstractmethod

# internal imports
from pyrestsdk.middleware import MiddlewarePipeline
from pyrestsdk.middleware import BaseMiddleware
from pyrestsdk.credential import AbstractBasicCredential

Logger = getLogger(__name__)

B = TypeVar("B", bound=BaseMiddleware)
C = TypeVar("C", bound=AbstractBasicCredential)

class AbstractHTTPClientFactory(ABC):

    session: Session

    def __init__(self, *, session: Session) -> None:
        self.session = session

    @abstractmethod
    def create_with_default_middleware(self, credential: C) -> Session:
        """Applies the default middleware chain to the HTTP Client
        """

    @abstractmethod
    def create_with_custom_middleware(self, middleware: B) -> Session:
        """Applies the custom middleware chain to the HTTP Client
        """

        raise NotImplementedError("create_with_custom_middleware is not implemented")

    @abstractmethod
    def _set_base_url(self) -> None:
        """Helper method to set the base url"""

    def _register(self, middleware: List[B]) -> None:
        """
        Helper method that constructs a middleware_pipeline with the specified middleware
        """

        Logger.info(f"{type(self)}._register: method called")

        if middleware:
            middleware_pipeline = MiddlewarePipeline()
            for ware in middleware:
                middleware_pipeline.add_middleware(ware)

            self.session.mount('https://', middleware_pipeline)

==> pyrestsdk-0.2.4.tar.gz: pyrestsdk-0.2.4/pyrestsdk/clientfactory/_abstract_client_factory.py <==
"""Houses Abstract HTTP Client Factory"""
from typing import TypeVar, List
from logging import getLogger
from abc import ABC, abstractmethod
from requests import Session
from pyrestsdk.middleware import MiddlewarePipeline
from pyrestsdk.middleware import BaseMiddleware
from pyrestsdk.credential import AbstractBasicCredential

Logger = getLogger(__name__)

B = TypeVar("B", bound=BaseMiddleware)
C = TypeVar("C", bound=AbstractBasicCredential)


class AbstractHTTPClientFactory(ABC):
    """Abstract HTTP Client Factory Type"""

    session: Session

    def __init__(self, /, session: Session) -> None:
        self.session = session

    @abstractmethod
    def create_with_default_middleware(self, credential: C) -> Session:
        """Applies the default middleware chain to the HTTP Client"""

    @abstractmethod
    def create_with_custom_middleware(self, middleware: B) -> Session:
        """Applies the custom middleware chain to the HTTP Client"""

        raise NotImplementedError("create_with_custom_middleware is not implemented")

    @abstractmethod
    def _set_base_url(self, url: str) -> None:
        """Helper method to set the base url"""

    def _register(self, middleware: List[B]) -> None:
        """
        Helper method that constructs a middleware_pipeline with the specified middleware
        """

        Logger.info("%s._register: method called", type(self))

        if middleware:
            middleware_pipeline = MiddlewarePipeline()
            for ware in middleware:
                middleware_pipeline.add_middleware(ware)

            self.session.mount("https://", middleware_pipeline)
